@@ -2,12 +2,14 @@
 Date         : 2022-10-25 17:21:52
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-11-08 10:52:53
+LastEditTime : 2022-11-08 15:14:00
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\model_evaluate.py
 Copyright (c) 2022 by BDFD, All Rights Reserved. 
 '''
+import pandas as pd
+import matplotlib.pyplot as plt
 import sklearn
 from sklearn.metrics import accuracy_score, confusion_matrix, precision_score, recall_score
 from sklearn.linear_model import LogisticRegression
@@ -65,4 +67,16 @@ def algo_accuracy(y_test, y_predict):
     algorithms_accuracy_result['recall_score'] = recall
     print(f'recall score is {recall}.',end='\n')
     
-    return algorithms_accuracy_result
\ No newline at end of file
+    return algorithms_accuracy_result
+
+def result_comparision(y_test, y_predict):
+    y_test = y_test.tolist()
+    y_predict = y_predict.tolist()
+    results = pd.DataFrame(data = {"Predictions":y_predict, "Actuals": y_test})
+    results["Matching"] = results.apply(lambda x: "Correct" if x["Predictions"] == x["Actuals"] else "Wrong", axis=1)
+    correct_wrong_data = results.groupby(["Actuals", "Matching"])["Predictions"].count().reset_index()
+    correct_wrong_data["Labels"] = correct_wrong_data["Actuals"] + " - " + correct_wrong_data["Matching"]
+    correct_wrong_data["Colors"] = correct_wrong_data["Matching"].map(lambda x: "b" if x == "Correct" else "r")
+    plt.figure(figsize=(18, 6))
+    fig = plt.bar(x=correct_wrong_data["Labels"], height=correct_wrong_data["Predictions"], color=correct_wrong_data["Colors"])
+    plt.show()
\ No newline at end of file
